@@ -110,7 +110,7 @@ def zones(self):
     self.add('AUTH', 'zones', 'custom_pages')
     self.add('AUTH', 'zones', 'dns_records')
     self.add('AUTH', 'zones', 'dns_records/export')
-    self.add('AUTH', 'zones', 'dns_records/import')
+    self.add('AUTH', 'zones', 'dns_records/import', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'zones', 'dns_records/scan')
     self.add('VOID', 'zones', 'dns_settings')
     self.add('AUTH', 'zones', 'dns_settings/use_apex_ns')
@@ -185,6 +185,15 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/waf')
     self.add('AUTH', 'zones', 'settings/webp')
     self.add('AUTH', 'zones', 'settings/websockets')
+    self.add('VOID', 'zones', 'settings/zaraz')
+    self.add('VOID', 'zones', 'settings/zaraz/v2')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/config')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/default')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/export')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/history')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/history/configs')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/publish')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/workflow')
 
 def zones_analytics(self):
     """ zones analytics """
@@ -399,7 +408,7 @@ def accounts(self):
 
     self.add('VOID', 'accounts', 'dlp')
     self.add('AUTH', 'accounts', 'dlp/datasets')
-    self.add('AUTH', 'accounts', 'dlp/datasets', 'upload')
+    self.add('AUTH', 'accounts', 'dlp/datasets', 'upload', content_type={'POST':'application/octet-stream'})
     self.add('VOID', 'accounts', 'dlp/patterns')
     self.add('AUTH', 'accounts', 'dlp/patterns/validate')
     self.add('AUTH', 'accounts', 'dlp/payload_log')
@@ -448,7 +457,7 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'storage/kv/namespaces')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'bulk')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'keys')
-    self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values')
+    self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
 
     self.add('AUTH', 'accounts', 'subscriptions')
@@ -458,9 +467,9 @@ def accounts(self):
     self.add('VOID', 'accounts', 'vectorize')
     self.add('AUTH', 'accounts', 'vectorize/index')
     self.add('AUTH', 'accounts', 'vectorize/indexes')
-    self.add('AUTH', 'accounts', 'vectorize/indexes', 'insert')
+    self.add('AUTH', 'accounts', 'vectorize/indexes', 'insert', content_type={'POST':'application/x-ndjson'})
     self.add('AUTH', 'accounts', 'vectorize/indexes', 'query')
-    self.add('AUTH', 'accounts', 'vectorize/indexes', 'upsert')
+    self.add('AUTH', 'accounts', 'vectorize/indexes', 'upsert', content_type={'POST':'application/x-ndjson'})
 
     self.add('AUTH', 'accounts', 'virtual_dns')
     self.add('VOID', 'accounts', 'virtual_dns', 'dns_analytics')
@@ -475,7 +484,7 @@ def accounts(self):
     self.add('VOID', 'accounts', 'workers/dispatch')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
-    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'settings')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'tags')
     self.add('AUTH', 'accounts', 'workers/domains')
@@ -485,15 +494,15 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'workers/queues')
     self.add('AUTH', 'accounts', 'workers/queues', 'consumers')
     self.add('AUTH', 'accounts', 'workers/scripts')
-    self.add('AUTH', 'accounts', 'workers/scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/scripts', 'content/v2')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
-    self.add('AUTH', 'accounts', 'workers/scripts', 'settings')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'settings', content_type={'PATCH':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
     self.add('AUTH', 'accounts', 'workers/scripts', 'usage-model')
     self.add('VOID', 'accounts', 'workers/services')
     self.add('VOID', 'accounts', 'workers/services', 'environments')
-    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/services', 'environments', 'settings')
     self.add('AUTH', 'accounts', 'workers/subdomain')
 
@@ -505,7 +514,7 @@ def accounts_addressing(self):
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'accounts')
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'ips')
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'zones')
-    self.add('AUTH', 'accounts', 'addressing/loa_documents')
+    self.add('AUTH', 'accounts', 'addressing/loa_documents', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', 'accounts', 'addressing/prefixes')
     self.add('VOID', 'accounts', 'addressing/prefixes', 'bgp')
@@ -559,7 +568,7 @@ def accounts_stream(self):
     self.add('AUTH', 'accounts', 'stream')
     self.add('AUTH', 'accounts', 'stream', 'audio')
     self.add('AUTH', 'accounts', 'stream', 'audio/copy')
-    self.add('AUTH', 'accounts', 'stream', 'captions')
+    self.add('AUTH', 'accounts', 'stream', 'captions', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'stream', 'embed')
     self.add('AUTH', 'accounts', 'stream', 'downloads')
     self.add('AUTH', 'accounts', 'stream', 'token')
@@ -568,7 +577,7 @@ def accounts_stream(self):
     self.add('AUTH', 'accounts', 'stream/direct_upload')
     self.add('AUTH', 'accounts', 'stream/keys')
 #   self.add('AUTH', 'accounts', 'stream/preview')
-    self.add('AUTH', 'accounts', 'stream/watermarks')
+    self.add('AUTH', 'accounts', 'stream/watermarks', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'stream/webhook')
     self.add('AUTH', 'accounts', 'stream/live_inputs')
     self.add('AUTH', 'accounts', 'stream/live_inputs', 'outputs')
@@ -666,7 +675,7 @@ def accounts_extras(self):
     """ extras """
 
     self.add('VOID', 'accounts', 'ai')
-    self.add('AUTH', 'accounts', 'ai/run')
+    self.add('AUTH', 'accounts', 'ai/run', content_type={'POST':['application/json','application/octet-stream']})
     self.add('AUTH', 'accounts', 'ai/run/proxy')
 
     self.add('VOID', 'accounts', 'alerting')
@@ -737,14 +746,14 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'gateway/rules')
 
     self.add('VOID', 'accounts', 'images')
-    self.add('AUTH', 'accounts', 'images/v1')
+    self.add('AUTH', 'accounts', 'images/v1', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'images/v1', 'blob')
     self.add('AUTH', 'accounts', 'images/v1/config')
     self.add('AUTH', 'accounts', 'images/v1/keys')
     self.add('AUTH', 'accounts', 'images/v1/stats')
     self.add('AUTH', 'accounts', 'images/v1/variants')
     self.add('AUTH', 'accounts', 'images/v2')
-    self.add('AUTH', 'accounts', 'images/v2/direct_upload')
+    self.add('AUTH', 'accounts', 'images/v2/direct_upload', content_type={'POST':'multipart/form-data'})
 
     self.add('VOID', 'accounts', 'intel')
     self.add('VOID', 'accounts', 'intel-phishing')
@@ -757,7 +766,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'intel/domain/bulk')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'data')
-    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'snapshot')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'snapshot', content_type={'PUT':'multipart/form-data'})
     self.add('VOID', 'accounts', 'intel/indicator-feeds/permissions')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/add')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/remove')
@@ -776,7 +785,7 @@ def accounts_extras(self):
 
     self.add('VOID', 'accounts', 'pages')
     self.add('AUTH', 'accounts', 'pages/projects')
-    self.add('AUTH', 'accounts', 'pages/projects', 'deployments')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments', content_type={'POST':'multipart/form-data'})
     self.add('VOID', 'accounts', 'pages/projects', 'deployments', 'history')
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'history/logs')
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'retry')
@@ -845,7 +854,7 @@ def zones_extras(self):
 
     self.add('VOID', 'zones', 'hostnames')
     self.add('AUTH', 'zones', 'hostnames/settings')
-    self.add('AUTH', 'zones', 'snippets')
+    self.add('AUTH', 'zones', 'snippets', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'zones', 'snippets', 'content')
     self.add('AUTH', 'zones', 'snippets/snippet_rules')
 
@@ -907,7 +916,7 @@ def zones_api_gateway(self):
     self.add('AUTH', 'zones', 'api_gateway/schemas')
     self.add('VOID', 'zones', 'api_gateway/settings')
     self.add('AUTH', 'zones', 'api_gateway/settings/schema_validation')
-    self.add('AUTH', 'zones', 'api_gateway/user_schemas')
+    self.add('AUTH', 'zones', 'api_gateway/user_schemas', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'zones', 'api_gateway/user_schemas', 'operations')
 
 
