@@ -41,7 +41,7 @@ def process_params_content_files(method, binary_file, args):
     while len(args) > 0 and ('=' in args[0] or args[0][0] == '@'):
         arg = args.pop(0)
         if arg[0] == '@':
-            # a file to be uploaded - used in workers/script - only via PUT
+            # a file to be uploaded - used in workers/script etc - only via PUT or POST
             filename = arg[1:]
             if method not in ['PUT','POST']:
                 sys.exit('cli4: %s - raw file upload only with PUT or POST' % (filename))
@@ -91,11 +91,14 @@ def process_params_content_files(method, binary_file, args):
             except ValueError:
                 sys.exit('cli4: %s="%s" - can\'t parse json value' % (tag_string, value_string))
         elif value_string[0] == '@':
-            # a file to be uploaded - used in dns_records/import - only via POST
+            # a file to be uploaded - used in dns_records/import etc - only via PUT or POST
             filename = value_string[1:]
-            if method != 'POST':
-                sys.exit('cli4: %s=%s - file upload only with POST' % (tag_string, filename))
-            files = {}
+            if method not in ['PUT', 'POST']:
+                sys.exit('cli4: %s=%s - file upload only with PUT or POST' % (tag_string, filename))
+            if files is None:
+                files = {}
+            if tag_string in files:
+                sys.exit('cli4: %s=%s - duplicate name' % (tag_string, filename))
             try:
                 if filename == '-':
                     files[tag_string] = sys.stdin
@@ -128,6 +131,15 @@ def process_params_content_files(method, binary_file, args):
                 sys.exit('cli4: %s=%s - param error. Can\'t mix unnamed and named list' %
                          (tag_string, value_string))
 
+    if content and params:
+        sys.exit('cli4: content and params not allowed together')
+
+    if params and files:
+        for k,v in params.items():
+            files[k] = (None, v)
+        params = None
+        # sys.exit('cli4: params and files not allowed together')
+
     return (params, content, files)
 
 def run_command(cf, method, command, params=None, content=None, files=None):
@@ -256,18 +268,13 @@ def run_command(cf, method, command, params=None, content=None, files=None):
                 sys.stderr.write('cli4: /%s - not found\n' % (command))
                 raise e
 
-    if content and params:
-        sys.stderr.write('cli4: /%s - content and params not allowed together\n' % (command))
-        raise Exception
-    if content:
-        params = content
-
     results = []
     if identifier2 is None:
         identifier2 = [None]
     for i2 in identifier2:
         try:
             if method == 'GET':
+                # no content with a GET call
                 r = m.get(identifier1=identifier1,
                           identifier2=i2,
                           identifier3=identifier3,
@@ -276,22 +283,22 @@ def run_command(cf, method, command, params=None, content=None, files=None):
                 r = m.patch(identifier1=identifier1,
                             identifier2=i2,
                             identifier3=identifier3,
-                            data=params)
+                            data=content)
             elif method == 'POST':
                 r = m.post(identifier1=identifier1,
                            identifier2=i2,
                            identifier3=identifier3,
-                           data=params, files=files)
+                           data=content, files=files)
             elif method == 'PUT':
                 r = m.put(identifier1=identifier1,
                           identifier2=i2,
                           identifier3=identifier3,
-                          data=params)
+                          data=content, files=files)
             elif method == 'DELETE':
                 r = m.delete(identifier1=identifier1,
                              identifier2=i2,
                              identifier3=identifier3,
-                             data=params)
+                             data=content)
             else:
                 pass
         except CloudFlare.exceptions.CloudFlareAPIError as e:
